from .input_file import InputFile
from .photosize import PhotoSize
from .file import BaseFile
from .document import Document
from .audio import Audio
from .contact import Contact
from .location import Location
from .video import Video
from .animation import Animation
